@@ -33,9 +33,19 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <assert.h>
-#include <time.h>
 #include <sys/uio.h>
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #ifdef HAVE_FAM 
  #include <fam.h>
 #endif
