@@ -32,11 +32,20 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <sys/utsname.h>
-#include <sys/time.h>
-#include <time.h>
 #include <netdb.h>
 #include <assert.h>
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #include <libprelude/common.h>
 #include <libprelude/prelude.h>
 #include <libprelude/prelude-log.h>
